==> formide-cli-1.0.9.tgz: package/lib/project.js <==
var fs			= require('fs');
var fs_extra 	= require('fs-extra')
var path		= require('path');
var _			= require('underscore');
var inquirer	= require('inquirer');
var request		= require('request');
var open		= require('open');
var archiver 	= require('archiver');
var semver		= require('semver');

var create = function(appPath) {
	// init project at given path or default to cwd
	appPath = (typeof appPath == 'string') ? appPath : process.cwd();
	
	// check if chosen path exists and is a directory
	if( !fs.existsSync(appPath) ) return console.error("Error: path does not exist");
	if( !fs.lstatSync(appPath).isDirectory() ) return console.error("Error: path is not a directory");
	
	// ask some questions to setup the project
	inquirer.prompt([
		{
			type: "input",
			name: "id",
			message: "What is your app ID? (can be found in the developers center)",
		},
		{
			type: "name",
			name: "name",
			message: "What is the name of your app?",
			default: "myFormideApp"
		},
		{
			type: "description",
			name: "description",
			message: "What is the description of your app?",
			default: "This is an awesome app!"
		},
		{
			type: "input",
			name: "version",
			message: "What is you app version? (fill in a semver compatible version number)",
			default: "1.0.0"
		},
		{
			type: "template",
			name: "template",
			message: "Which starter template? (leave empty or choose from basic, 3dviewer)"
		},
		{
			type: "confirm",
			name: "confirm",
			message: "Use this config?"
		}
	], function(input) {
		var projectPath = path.join(appPath, input.name);
		
		// check if version valid
		if(semver.valid(input.version) == null) {
			return console.log("Version number invalid, make sure you use a valid semver version number".red);
		}
		
		// check if dir already exists
		if (fs.existsSync(projectPath)) return console.log(("Error: path " + projectPath + " already exist").red);
		
		// copy chosen template
		if(input.template) {
			// copy project dir
			if (fs.existsSync(__dirname + "/../templates/" + input.template)) {
				fs_extra.copySync(__dirname + "/../templates/" + input.template, projectPath);
			}
			else {
				return console.log(("Error: template does not exist").red);
			}
		}
		else {
			// create project dir
			fs.mkdirSync(projectPath);
		}
		
		// build manifest
		var manifest = {
			id: input.id,
			name: input.name,
			version: input.version
		};
		
		// add author when logged in
		if (typeof lib.settings.user == 'object') {
			manifest.author = {
				name: lib.settings.user.firstname + " " + lib.settings.user.lastname,
				email: lib.settings.user.email	
			};
		}
		
		// create app.json
		fs.writeFileSync(path.join(projectPath, 'app.json'), JSON.stringify(manifest, null, 4));
		
		// create README.md
		fs.writeFileSync(path.join(projectPath, 'README.md'), "# " + input.name + "\n" +input.description);
		
		// wait a bit and exit
		setTimeout(process.exit, 1000);
	});
};

var info = function() {
	// run project at given path or default to cwd
	appPath = (typeof appPath == 'string') ? appPath : process.cwd();
	
	// get manifest contents for upload info
	var manifest = fs.readFileSync(appPath + '/app.json', 'utf8');
	manifest = JSON.parse(manifest);
	
	// show manifest contents
	console.log(manifest);
	
	// wait a bit and exit
	setTimeout(process.exit, 1000);
};

var run = function() {
	// run project at given path or default to cwd
	appPath = (typeof appPath == 'string') ? appPath : process.cwd();
	
	// open local app index.html in browser
	open('file://' + appPath + '/index.html');
	
	// wait a bit and exit
	setTimeout(process.exit, 1000);
};

var publish = function(appPath) {
	// publish project at given path or default to cwd
	appPath = (typeof appPath == 'string') ? appPath : process.cwd();
	
	// get manifest contents for upload info
	var manifest = fs.readFileSync(appPath + '/app.json', 'utf8');
	manifest = JSON.parse(manifest);
	
	// compress and upload app
	compress(appPath, manifest, function(err, zipPath) {
		upload(zipPath, manifest, function(err, httpResponse, body) {
			
			// remove zipfile
			fs.unlink(zipPath);
			
			var response = JSON.parse(body);
			if(!response.success) {
				return console.log(('Upload failed: ' + response.message).red);
			}
			
			// patch bump manifest version number
			manifest.version = semver.inc(manifest.version, 'patch');
			fs.writeFileSync(appPath + '/app.json', JSON.stringify(manifest), 'utf8');
			
			// log success
			console.log(('Upload complete').green);
			
			// wait a bit and exit
			setTimeout(process.exit, 1000);
		});
	});
};

var compress = function(appPath, manifest, callback) {
	var zipPath = appPath + '/app.zip';
	var zip = fs.createWriteStream(zipPath);
	var archive = archiver('zip');
	
	archive.pipe(zip);
	archive.bulk([{
		expand: true,
		cwd: appPath,
		src: ['**']
	}]);
	
	archive.finalize(function(err, bytes) {
		if(err) {
			console.log(err);
		}
	});
	
	zip.on('close', function() {
		callback(null, zipPath);
	});
};

var upload = function(zipPath, manifest, callback) {
	lib.api.call({
		path: '/apps/upload',
		method: 'POST',
		json: false,
		appUpload: {
			version: manifest.version,
			id: manifest.id,
			zipPath: zipPath
		}
	}, callback);
};

module.exports.create = create;
module.exports.publish = publish;
module.exports.run = run;
module.exports.info = info;

==> formide-cli-1.0.11.tgz: package/lib/project.js <==
var fs			= require('fs');
var fs_extra 	= require('fs-extra')
var path		= require('path');
var _			= require('underscore');
var inquirer	= require('inquirer');
var request		= require('request');
var open		= require('open');
var archiver 	= require('archiver');
var semver		= require('semver');

var create = function(appPath) {
	// init project at given path or default to cwd
	appPath = (typeof appPath == 'string') ? appPath : process.cwd();
	
	// check if chosen path exists and is a directory
	if( !fs.existsSync(appPath) ) return console.error("Error: path does not exist");
	if( !fs.lstatSync(appPath).isDirectory() ) return console.error("Error: path is not a directory");
	
	// ask some questions to setup the project
	inquirer.prompt([
		{
			type: "input",
			name: "id",
			message: "What is your app ID? (can be found in the developers center)",
		},
		{
			type: "name",
			name: "name",
			message: "What is the name of your app?",
			default: "myFormideApp"
		},
		{
			type: "description",
			name: "description",
			message: "What is the description of your app?",
			default: "This is an awesome app!"
		},
		{
			type: "input",
			name: "version",
			message: "What is you app version? (fill in a semver compatible version number)",
			default: "1.0.0"
		},
		{
			type: "template",
			name: "template",
			message: "Which starter template? (leave empty or choose from basic, 3dviewer)"
		},
		{
			type: "confirm",
			name: "confirm",
			message: "Use this config?"
		}
	], function(input) {
		var projectPath = path.join(appPath, input.name);
		
		// check if version valid
		if(semver.valid(input.version) == null) {
			return console.log("Version number invalid, make sure you use a valid semver version number".red);
		}
		
		// check if dir already exists
		if (fs.existsSync(projectPath)) return console.log(("Error: path " + projectPath + " already exist").red);
		
		// copy chosen template
		if(input.template) {
			// copy project dir
			if (fs.existsSync(__dirname + "/../templates/" + input.template)) {
				fs_extra.copySync(__dirname + "/../templates/" + input.template, projectPath);
			}
			else {
				return console.log(("Error: template does not exist").red);
			}
		}
		else {
			// create project dir
			fs.mkdirSync(projectPath);
		}
		
		// build manifest
		var manifest = {
			id: input.id,
			name: input.name,
			version: input.version
		};
		
		// add author when logged in
		if (typeof lib.settings.user == 'object') {
			manifest.author = {
				name: lib.settings.user.firstname + " " + lib.settings.user.lastname,
				email: lib.settings.user.email	
			};
		}
		
		// create app.json
		fs.writeFileSync(path.join(projectPath, 'app.json'), JSON.stringify(manifest, null, 4));
		
		// create README.md
		fs.writeFileSync(path.join(projectPath, 'README.md'), "# " + input.name + "\n" +input.description);
		
		// wait a bit and exit
		setTimeout(process.exit, 1000);
	});
};

var info = function() {
	// run project at given path or default to cwd
	appPath = (typeof appPath == 'string') ? appPath : process.cwd();
	
	// get manifest contents for upload info
	var manifest = fs.readFileSync(appPath + '/app.json', 'utf8');
	manifest = JSON.parse(manifest);
	
	// show manifest contents
	console.log(manifest);
	
	// wait a bit and exit
	setTimeout(process.exit, 1000);
};

var run = function() {
	// run project at given path or default to cwd
	appPath = (typeof appPath == 'string') ? appPath : process.cwd();
	
	// open local app index.html in browser
	open('file://' + appPath + '/index.html');
	
	// wait a bit and exit
	setTimeout(process.exit, 1000);
};

var publish = function(appPath) {
	// publish project at given path or default to cwd
	appPath = (typeof appPath == 'string') ? appPath : process.cwd();
	
	// get manifest contents for upload info
	var manifest = fs.readFileSync(appPath + '/app.json', 'utf8');
	manifest = JSON.parse(manifest);
	
	// compress and upload app
	compress(appPath, manifest, function(err, zipPath) {
		upload(zipPath, manifest, function(err, httpResponse, body) {
			
			// remove zipfile
			fs.unlink(zipPath);
			
			// handle upload error
			if (err) {
				return console.log(('Upload failed: ' + err.message).red);
			}
			
			try {
				var response = JSON.parse(body);
				
				// handle not 200 OK response from api as error
				if (httpResponse.statusCode !== 200) {
					return console.log(('Upload failed: ' + response.message).red);
				}
				
				// patch bump manifest version number
				manifest.version = semver.inc(manifest.version, 'patch');
				fs.writeFileSync(appPath + '/app.json', JSON.stringify(manifest), 'utf8');
				
				// log success
				console.log(('Upload complete: ' + response.message).green);
				
				// wait a bit and exit
				setTimeout(process.exit, 1000);
			}
			catch (e) {
				return console.log(('Upload failed: ' + e.message).red);
			}
		});
	});
};

var compress = function(appPath, manifest, callback) {
	var zipPath = appPath + '/app.zip';
	var zip = fs.createWriteStream(zipPath);
	var archive = archiver('zip');
	
	archive.pipe(zip);
	archive.bulk([{
		expand: true,
		cwd: appPath,
		src: ['**']
	}]);
	
	archive.finalize(function(err, bytes) {
		if(err) {
			console.log(err);
		}
	});
	
	zip.on('close', function() {
		callback(null, zipPath);
	});
};

var upload = function(zipPath, manifest, callback) {
	lib.api.call({
		path: '/apps/upload',
		method: 'POST',
		json: false,
		appUpload: {
			version: manifest.version,
			id: manifest.id,
			zipPath: zipPath
		}
	}, callback);
};

module.exports.create = create;
module.exports.publish = publish;
module.exports.run = run;
module.exports.info = info;
